#
# spec file for package telegram-desktop
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           telegram-desktop
Version:        1.6.7
Release:        lp151.1.1
Summary:        Messaging application with a focus on speed and security
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
URL:            https://github.com/telegramdesktop/tdesktop
Source0:        https://github.com/telegramdesktop/tdesktop/archive/v%{version}.tar.gz
# curl https://chromium.googlesource.com/breakpad/breakpad/+archive/refs/heads/master.tar.gz -o breakpad-master.tar.gz
Source1:        breakpad-master.tar.gz
# curl https://chromium.googlesource.com/linux-syscall-support/+archive/master.tar.gz -o linux-syscall-support-refs-heads-master.tar.gz
Source2:        linux-syscall-support-refs-heads-master.tar.gz
# curl https://chromium.googlesource.com/external/gyp/+archive/master.tar.gz -o gyp-master.tar.gz
Source3:        gyp-master.tar.gz
Source4:        patch.py
# curl https://codeload.github.com/Microsoft/GSL/zip/master -o GSL-master.zip
Source5:        GSL-master.zip
# curl https://codeload.github.com/mapbox/variant/zip/master -o variant-master.zip
Source6:        variant-master.zip
# curl https://codeload.github.com/grishka/libtgvoip/zip/public -o libtgvoip.zip
Source7:        libtgvoip.zip
# curl https://raw.githubusercontent.com/philsquared/Catch/master/single_include/catch.hpp -o catch.hpp
Source8:        catch.hpp
# curl https://codeload.github.com/ericniebler/range-v3/zip/master -o range-v3-master.zip
Source9:        range-v3-master.zip
# curl https://codeload.github.com/telegramdesktop/crl/zip/master -o crl-master.zip
Source10:       crl-master.zip
# curl https://codeload.github.com/Cyan4973/xxHash/zip/master -o crl-master.zip
Source11:       xxHash-master.zip

Patch0:         tdesktop.patch
Patch1:         gcc7-fix.patch
BuildRequires:  chrpath
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  ffmpeg-devel
BuildRequires:  fontconfig-devel
BuildRequires:  freetype-devel
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  libQt5DBus-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5Network-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  libXfixes-devel
BuildRequires:  libexpat-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmng-devel
BuildRequires:  libopus-devel
BuildRequires:  libproxy-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  libqt5-qtimageformats-devel
BuildRequires:  libtiff-devel
BuildRequires:  minizip-devel
BuildRequires:  openal-soft-devel
BuildRequires:  opusfile-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  portaudio-devel
# python2-base is required for gyp, Auto pulled in for Tumbleweed, but need for Leap 15.
BuildRequires:  python2-base
BuildRequires:  python3
BuildRequires:  unzip
BuildRequires:  xcb-util-image-devel
BuildRequires:  xcb-util-keysyms-devel
BuildRequires:  xcb-util-renderutil-devel
BuildRequires:  xcb-util-wm-devel
BuildRequires:  xorg-x11-devel
BuildRequires:  xz
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(appindicator-0.1)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-glx)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(mtdev)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(tslib)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbcommon-x11)
# Runtime requirements
Requires:       ffmpeg
Requires:       hicolor-icon-theme
Requires:       icu
Requires:       jasper
Requires:       openssl
ExclusiveArch:  x86_64

%description
Telegram is a non-profit cloud-based instant messaging service.
Users can send messages and exchange photos, videos, stickers, audio and files of any type.
Its client-side code is open-source software but the source code for recent versions is not
always immediately published, whereas its server-side code is closed-source and proprietary.
The service also provides APIs to independent developers.

%prep
%setup -q -n tdesktop-%{version}
cp %{SOURCE8} Telegram/SourceFiles/base

# Already included in %{S:8}
sed -i "/catch_reporter_compact.hpp/d" Telegram/SourceFiles/base/tests_main.cpp

cp %{_sourcedir}/GSL-master.zip . && unzip GSL-master.zip
mv GSL-master GSL
mv GSL %{_builddir}/tdesktop-%{version}/Telegram/ThirdParty/

cp %{_sourcedir}/variant-master.zip . && unzip variant-master.zip
mv variant-master variant
mv variant %{_builddir}/tdesktop-%{version}/Telegram/ThirdParty/

cp %{_sourcedir}/libtgvoip.zip . && unzip libtgvoip.zip
mv libtgvoip-public libtgvoip
mv libtgvoip %{_builddir}/tdesktop-%{version}/Telegram/ThirdParty/

cp %{_sourcedir}/range-v3-master.zip . && unzip range-v3-master.zip
mv range-v3-master range-v3
mkdir -p %{_builddir}/Libraries
mv range-v3 %{_builddir}/Libraries/

cp %{_sourcedir}/crl-master.zip . && unzip crl-master.zip
mv crl-master crl
mv crl %{_builddir}/tdesktop-%{version}/Telegram/ThirdParty/

cp %{_sourcedir}/xxHash-master.zip . && unzip xxHash-master.zip
mv xxHash-master xxHash
mv xxHash %{_builddir}/tdesktop-%{version}/Telegram/ThirdParty/

cp %{_sourcedir}/tdesktop.patch %{_builddir}/tdesktop-%{version}
cd %{_builddir}/tdesktop-%{version}
%patch0 -p1
%if 0%{?sle_version} == 150000 && 0%{?is_opensuse}
%patch1 -p1
%endif

cp %{_sourcedir}/patch.py . && python3 ./patch.py
cp %{_sourcedir}/catch.hpp ./Telegram/SourceFiles/

%setup -q -T -c -n breakpad -a 1
%setup -q -T -c -n breakpad-lss -a 2
%setup -q -T -c -n gyp -a 3

%build
mv %{_builddir}/tdesktop-%{version} %{_builddir}/tdesktop

# patch gyp
cd %{_builddir}/Libraries
ln -s %{_builddir}/gyp
cp %{_builddir}/tdesktop/Telegram/Patches/gyp.diff gyp
cd gyp
patch -p1 < gyp.diff

# Build breakpad
cd %{_builddir}/breakpad
ln -s %{_builddir}/breakpad-lss src/third_party/lss
%configure
%make_build
make install DESTDIR=%{_builddir}/Libraries/breakpad

cd %{_builddir}/tdesktop/Telegram/gyp
# patch qt.gypi to change libxkbcommon path
%{_builddir}/Libraries/gyp/gyp \
    -Dapi_id=340630 \
    -Dapi_hash=98a22f733eac40f1bd187a30d19271de \
    -Dlinux_lib_ssl=-lssl \
    -Dlinux_lib_crypto=-lcrypto \
    -Dlinux_lib_icu="-licuuc -licutu -licui18n" \
    -Dlinux_path_opus_include="%{_includedir}/opus" \
    -Dlinux_path_breakpad="%{_builddir}/Libraries/breakpad%{_prefix}" \
    -Gconfig=Release \
    --depth=. --generator-output="%{_builddir}/tdesktop" -Goutput_dir=out Telegram.gyp --format=cmake

# build Telegram
cd %{_builddir}/tdesktop/out/Release
%cmake ..
sed -i 's,breakpad/usr/lib,breakpad%{_libdir},' ./CMakeFiles/Telegram.dir/link.txt
make %{?_smp_mflags}
chrpath --delete Telegram

%install
# Install binary
install -dm755 %{buildroot}%{_bindir}
install -m755 %{_builddir}/tdesktop/out/Release/build/Telegram %{buildroot}%{_bindir}/%{name}

# Install desktop file
install -d %{buildroot}%{_datadir}/applications
desktop-file-install \
    --dir %{buildroot}%{_datadir}/applications \
    --add-category InstantMessaging \
    %{_builddir}/tdesktop/lib/xdg/telegramdesktop.desktop

# Install protocol
install -d %{buildroot}%{_datadir}/kservices5
install -m644 %{_builddir}/tdesktop/lib/xdg/tg.protocol \
	%{buildroot}%{_datadir}/kservices5/tg.protocol

# Install icons
for icon_size in 16 32 48 64 128 256 512; do
    icon_dir="%{buildroot}%{_datadir}/icons/hicolor/${icon_size}x${icon_size}/apps"
    install -d "${icon_dir}"
    install -m644 "%{_builddir}/tdesktop/Telegram/Resources/art/icon${icon_size}.png" \
	    "${icon_dir}/telegram.png"
done

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(0664,root,root,-)
%license LICENSE
%doc README.md
%attr(0755,root,root) %{_bindir}/%{name}
%{_datadir}/applications/telegramdesktop.desktop
%dir %{_datadir}/kservices5
%{_datadir}/kservices5/tg.protocol
%{_datadir}/icons/hicolor/*/apps/telegram.png

%changelog
* Sat Apr 13 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.7
  * Replace media when editing messages with media content.
  * Jump quickly to the top of your chats list.
  * Get emoji suggestions for the first word you type in a message.
  * Help Telegram improve emoji suggestions in your language using
    this interface https://translations.telegram.org/en/emoji
* Thu Apr 11 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.6
  * Bug fixes and other minor improvements.
* Sat Apr  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.5
  * Bug fixes and other minor improvements.
* Fri Apr  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.4
  * Replace media when editing messages with media content.
  * Jump quickly to the top of your chats list.
  * Get emoji suggestions for the first word you type in a message.
  * Help Telegram improve emoji suggestions in your language using
    this interface https://translations.telegram.org/en/emoji
* Sun Mar 24 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.2
  * Delete any message on both ends in any private chat, anytime.
  * Control whether your forwarded messages link back to your account.
  * Control who may see your profile picture.
  * Enjoy the new streamlined group management screen.
* Wed Mar 20 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.1
  * Play video files and listen to received music without
    waiting for them to download.
  * Press CTRL+0 (CMD+0 on macOS) to jump to your Saved Messages.
  * Bug fixes and other minor improvements.
- Apply gcc7-fix patch on Leap 15.0 only
* Thu Feb 21 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Do not apply gcc7-fix.patch on Tumbleweed
* Wed Feb 20 2019 ramaxlo@gmail.com
- Fix build failure for openSUSE Leap 15.0.
* Tue Feb 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.15
  * Crash fix.
* Tue Feb 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.13
  * Bug fixes and other minor improvements.
* Sat Feb  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.12
  * Apply blur effects to backgrounds.
  * Use the backgrounds you set in Telegram Desktop in all other Telegram apps.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.11
  * Bug fixes and other minor improvements.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.10
  * Bug fixes and other minor improvements.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.9
  * Bug fixes and other minor improvements.
* Tue Jan 22 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.8
  * Global permissions for groups. Restrict all members in any
    group from posting certain types of content.
  * Unified group settings. Make groups public, set admins with
    granular permissions and toggle persistent history in just a
    few clicks in any group.
  * Choose the emoji set you would like to use in Chat Settings.
  * Choose input and output devices for Telegram Calls in
    Settings > Advanced > Call Settings.
  * Support for automatically downloading files and music.
* Fri Jan 11 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.4
  * Bug fixes and other minor improvements.
  * Create polls in groups and channels - right from the chat menu.
* Thu Jan 10 2019 Ramax Lo <ramaxlo@gmail.com>
- Add TDESKTOP_DISABLE_OPENAL_EFFECTS to fix playback error:
  Audio Playback Error: 40963, Invalid Value
* Sat Dec 22 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.5.2
  * Bug fixes and other minor improvements.
  * Support for custom languages.
  * Interface scaling for large screens.
  * Video messages displayed in shared media.
* Sat Nov 17 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.4.7
  * Crash fix.
  * Bug fixes and other minor improvements
  * Listen to voice and video messages in 2X mode if you're in a hurry.
  * Find video messages in the shared voice messages section.
  * Add a comment when you share posts from channels.
  * View all photos and videos in Twitter and Instagram link previews.
  * Interface scaling for large screens, up to 300%% (up to 150%% for macOS retina screens).
  * Updated emoji.
- Add api_id and api_hash to build
* Thu Oct 11 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.4.2
  * Crash fix.
  * Reduce crashes due to the out of memory exceptions.
  * Load map previews through mtproto.
  * Bug fixes and other minor improvements.
  * Fully redesigned Settings section.
  * New theme selector in Chat Settings.
  * New local storage settings: Control how much disk space is used by the cache and for how long the cached files are stored.
  * Improved local caching for images and GIF animations.
  * New settings: Peer-to-Peer settings for calls, disable animations for low performance computers.
  * Various other improvements.
* Tue Sep 18 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid repeating name in summary.
* Mon Sep  3 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.3.15
  * Improved local files cache.
  * Move to use kservices5.
* Fri Jul 27 2018 i@xuzhao.net
- Update to 1.3.10
  * Bug fixes adn other minor improvements.
- Changes in 1.3.9
  * Mark chats in the chat list as Read or Unread.
  * Improved censorship circumvention.
* Sat Jun  2 2018 duyizhaozj321@yahoo.com
- Update to 1.3.0
  * Improved censorship circumvention.
  * Improved stability when working through proxy servers.
  * Save several proxy servers to quickly switch between them in Settings.
  * Use proxy for calls.
  * Emoji and text replacement now happens immediately after typing (instead of after sending) and can
    be rolled back using Backspace or CTRL/CMD + Z. Replacement no longer happens when pasting text.
- Changes in 1.2.25
  * Apply markdown formatting (```, `, **, __) only when sending the message.
  * Display connection quality bars in calls.
  * Telegram Desktop can update itself through MTProto.
  * Bug fixes and other minor improvements.
* Sun May 27 2018 duyizhaozj321@yahoo.com
- Update to 1.2.24
  * Add links with custom text from context menu or by Ctrl/Cmd + K keyboard shortcut.
* Sat May 26 2018 duyizhaozj321@yahoo.com
- Update to 1.2.23
  * Apply formatting from input field context menu.
  * Apply formatting by hotkeys.
  * Bug fixes and other minor improvements.
* Fri May 25 2018 i@xuzhao.net
- Update to 1.2.22
  * Use markdown in media captions (bold, italic, tag and code).
  * Use emoji replacement in media captions, group and channel titles and descriptions (:like: etc.)
  * Markdown replacement now happens immediately after typing (instead of after sending) and can be rolled back using Backspace or Ctrl/Cmd + Z.
    Replacement no longer happens when pasting text.
* Mon Apr 16 2018 ilya@ilya.pp.ua
- Update to 1.2.17
  * Bug fixes and other minor improvements.
* Wed Mar 28 2018 ilya@ilya.pp.ua
- Update to 1.2.15
  * Discover new stickers. Type one emoji to see suggestions from
    popular sticker sets. Suggestions from your installed sticker
    sets will come first.
  * Search for Stickers. Click on the new search icon to access
    your sticker sets or find new ones.
  * Use fast reply button in group chats.
  * Select a message you want to reply to by pressing Ctrl+Up and
    Ctrl+Down.
* Tue Mar 20 2018 ilya@ilya.pp.ua
- Refresh spec-file via spec-cleaner and manual optimizations.
  * Add %%license and %%doc macros.
  * Remove Leap/SLE support for version < 15.
  * Increment to 4 GB of RAM for a more stable build.
  * Change Description and Summary.
* Mon Feb 26 2018 badshah400@gmail.com
- Use -a instead of -b to \%%setup to fix buing on openSUSE >=
  1500; this behaviour changed with rpm 4.14.
- Add BuildRequires: python2-base as python2 executable is needed
  for gyp scripts. It was being automatically pulled in for
  Factory, but not for Leap:15.0.
* Fri Jan 12 2018 badshah400@gmail.com
- Add Requires: libqt5-qtimageformats; required to show images of
  any kind (emoji, stickers, etc.) in the interface since the
  switch to system Qt5.
* Sun Dec 31 2017 badshah400@gmail.com
- Update to version 1.2.6:
  * Grouped Photos: Group media into an album when sharing
    multiple photos and videos. Choose the exact order of media
    you send.
  * Bug fixes and other minor improvements.
- Add crl-master.zip from https://github.com/telegramdesktop/crl
  and copy it to build dir appropriately; this is now required
  for building.
- Rebase tdesktop.patch.
* Mon Dec 18 2017 badshah400@gmail.com
- Update to version 1.2.1:
  * Bug fixes and other minor improvements.
* Fri Dec 15 2017 badshah400@gmail.com
- update patch.py to remove dee-1.0 dependency, which is not in
  use any more, and not available from factory, thus resolving
  unresolvable status.
* Wed Dec 13 2017 badshah400@gmail.com
- Update minimal versions of gcc and cmake in BuildRequires in
  keeping with upstream: gcc >= 7 (7.2) is now needed. Also update
  the gcc command exported before building on openSUSE <= 1320 to
  gcc-7.
* Mon Dec 11 2017 badshah400@gmail.com
- Update to version 1.2.0:
  * Radically improved navigation. New side panel on the right
    with quick access to shared media and group members.
  * Saved Messages. Bookmark messages by forwarding them to "Saved
    Messages". Access them from the Chats list or from the side
    menu.
  * Pinned Messages. If you are a channel admin, pin messages to
    focus your subscribers' attention on important announcements.
  * Easily recognize messages from group admins by the new 'admin'
    badge.
  * Also supported clearing history in supergroups and added a
    host of minor improvements.
- Disable parallel make for main app because the build job becomes
  terribly slow, and eventually runs out of memory otherwise.
* Fri Sep  8 2017 badshah400@gmail.com
- Update to version 1.1.23:
  * See the message author photo and name while searching specific
    chat messages.
  * Fix "Send To" menu action on Windows.
- Rebase and rename patch-1.1.19.diff to patch-1.1.23.diff.
- Add catch.hpp as source and copy to required dir; remove
  includes referring to subdirs of catch as we are using the one
  header version.
- Refresh all third-party sources to their current versions.
- Add breakpad-ucontext_t-glibc2_26.patch: Replace
  `struct ucontext` by `ucontext_t` to make breakpad compatible
  with glib-2.26; merged upstream as commit e3035bc; only apply
  for openSUSE > 1320.
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 1.1.19:
  * Search by messages of specific group members.
  * Bug fixes and other minor improvements.
- Update name of patch-1.1.18.diff to patch-1.1.19.diff (no
  rebase was needed).
* Thu Jul 27 2017 badshah400@gmail.com
- Update to version 1.1.18:
  * Minor bug fixes.
- Update name of patch-1.1.17.diff to patch-1.1.18.diff (no
  rebase was needed).
* Wed Jul 26 2017 badshah400@gmail.com
- Update to version 1.1.17:
  * Minor bug fixes.
- Update to version 1.1.16:
  * Autocompletion for emoji. Start typing :e to get suggestions.
  * Fixed a bug with forwarding messages.
- Update patch-1.1.15.diff to patch-1.1.17.diff (minor rebase).
* Mon Jul 24 2017 badshah400@gmail.com
- Update to version 1.1.15:
  * Send bold and italic text in your messages.
  * Get a share link for posts in public supergroups.
  * Quickly share posts from channels and media messages from
    bots.
  * Search large supergroup members by name.
  * Search channel members by name for admins.
  * Use search in the service actions log.
  * Ban supergroup members via the right click menu in the service
    actions log.
- Update name of patch-1.1.10.diff to patch-1.1.15.diff (no
  rebase was needed).
* Tue Jul 11 2017 badshah400@gmail.com
- Use post(un) scriptlets to update hicolor icon-theme cache, and
  the desktop database; without these the desktop menu icon does
  not get registered to the icon and picks up a default ugly icon,
  until subsequent installation of other programs or manual
  invocation of the commands corresponding to these scriptlets.
* Sat Jul  8 2017 badshah400@gmail.com
- Update to version 1.1.10:
  * Add event log filter for channel or supergroup event log.
  * Fix search by username in privacy exceptions editor.
  * Fix adding admins in channels.
* Sun Jul  2 2017 badshah400@gmail.com
- Update to version 1.1.9:
  * Supergroups can now have up to 10.000 members.
  * Appoint supergroup admins with granular rights. Choose who can
    add users, manage messages, block members, edit group info &
    username, add new admins, etc.
  * Restrict and ban supergroup members with granular precision.
    Read-only bans, GIF & sticker bans, media bans, temporary bans
    and restrictions.
  * Check the new event log to see all service actions taken by
    members and admins of a channel or supergroup in the last 48
    hours.
  * Toggle night mode in the main menu.
- Rebase patch-%%{version}.diff for updated version.
- Enforce strict version dependence for BuildRequires on
  libtelegram-qt5-devel-static = 5.6.2, since telegram does not
  build with older versions any more. Pass -Dqt_version="5.6.2"
  instead of -Dqt_version="5.6.0" when configuring for build with
  gyp.
* Wed Jun 21 2017 badshah400@gmail.com
- For openSUSE Leap, use gcc6 from the Update repository (gcc6
  from OSS is uninstallable).
- Add a _constraints file to restrict building to hardware with at
  2 GB of physical memory.
* Sun Jun  4 2017 badshah400@gmail.com
- Update to version 1.1.7.
- Add libtgvoip.zip to sources, required to build Telegram
- Rebase patch-1.0.29.diff for updated version; rename to
  patch-%%{version}.diff.
- New BuildRequires: pkgconfig(libpulse), pkgconfig(alsa); needed
  to build Telegram with audio/video support.
* Sun Apr 30 2017 badshah400@gmail.com
- Update to version 1.0.29.
- Use full URL for telegram-desktop source.
- Require gcc-c++ >= 5.0, since support for -std=gnu++14 is now
  required; on openSUSE versions <= 1320 using gcc5 or gcc6
  nonetheless leads to build failures.
- Update icon file name in keeping with upstream.
- Rebase patch-1.0.24.diff for updated version; rename it to
  patch-1.0.29.diff.
* Mon Jul 18 2016 badshah400@gmail.com
- Add %%post scriptlets to update icon theme cache and desktop
  database (BuildRequires: hicolor-icon-theme, Requires(post):
  desktop-file-utils).
- Use full URL for source.
- Run through spec-cleaner to clean up spec file according to
  openSUSE guidelines.
* Mon Jul  4 2016 i@xuzhao.net
- Upgrade to 0.9.56
- Fixed photo viewer to handle screen resolution change correctly.
- Fixed forwarding photos via drag-n-drop.
- Various design improvements and other bug fixes.
* Mon May 16 2016 i@xuzhao.net
- 0.9.48 Initial Commit.
